/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.extension;

import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.model.constraints.IConstraintContainer;
import org.fortiss.tooling.kernel.model.constraints.IConstraintVerificationStatus;
import org.fortiss.tooling.kernel.service.base.IEObjectAware;

/**
 * Interface for the GUI of constraint verifiers.
 * 
 * @author aravantinos
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: FF8F3F170CD5768D578035D3803F7470
 */
public interface IConstraintVerifierUI<T extends IConstraint> extends IEObjectAware<T> {

	/**
	 * Action to take when trying to open the given constraint. <code>canOpen</code> should be
	 * called before to know if the status can be opened.
	 * 
	 * @param constraint
	 * @param status
	 * @return true if the constraint could indeed be open, false if it needs further handling.
	 */
	public boolean openStatus(T constraint, IConstraintVerificationStatus status);

	/** True if the constraint can be open. */
	boolean canOpen(T constraint, IConstraintVerificationStatus status);

	/** Method to execute when a constraint gets outdated. */
	public void onOutdate(T constraint);

	/** Returns a short user-friendly description explaining the constraint. */
	public String getMessage(T constraint, IConstraintVerificationStatus status);

	/**
	 * The following features deal with the usage of constraints to drive the process.
	 * 
	 * EXPERIMENTAL.
	 */

	/**
	 * Hook to run when the constraint is activated. Can be used to add constraints that would be
	 * missing.
	 */
	public void onActivate(IConstraintContainer context);

	/** Gets a general description for the constraint type. */
	String getDescription();

	/** True if this constraint shall be displayed as a development process constraint. */
	boolean isUsableForDevelopmentProcess();
}
